import matplotlib.pyplot as plt
from libPureConduction import *


# material properties
lambda_c    = 60	                # thermal conductivity heavy metal (bottom/cathode)
lambda_sC   = 0.084	                # thermal conductivity heavy salt (bottom/salt)
lambda_sA   = 0.84	                # thermal conductivity light salt (top/salt)
lambda_a    = 63	                # thermal conductivity light metal (top/anode)

h_c         = 8e-3                      # height cathode
h_sC        = 20e-3                     # height salt on cathode side
h_sA        = 20e-3                     # height salt on anode side
h_a         = 13e-3                     # height anode
H           = h_c+h_sC+h_sA+h_a;    # height of the cell

T_ref       = 600 + 273.15	        # reference temperature

j           = 0.1e4	    		# current density in A/m²
sigma_sC    = 92;                   	# electric conductivity lower salt
sigma_sA    = 138;			# electric conductivity upper salt


###############################################################################
# SIMPLE PURE CONDUCTION

# define figure
f = plt.figure(1)
ax = f.subplots()
#f.set_size_inches(1.5,3)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis="x", labelsize=10)
ax.tick_params(axis="y", labelsize=10)

T_PC_a, T_PC_sA, T_PC_sC, T_PC_c, z_a, z_sA, z_sC, z_c = deltaT(j, T_ref, lambda_a, lambda_sA, lambda_sC, lambda_c, sigma_sA, sigma_sC, h_a, h_sA, h_sC, h_c, 1000)

# Plot (T,z)
ax.plot(T_PC_c,  z_c*1e3,  linewidth=4, color='k')
ax.plot(T_PC_sC, z_sC*1e3, linewidth=4, color='k')
ax.plot(T_PC_sA, z_sA*1e3, linewidth=4, color='k')
ax.plot(T_PC_a,  z_a*1e3,  linewidth=4, color='k')

plt.title('analytical solution')
plt.ylim( (0, H*1e3) )
#plt.xlim(0,0.4)

ax.set(xlabel=r"$\Delta T$ in K", ylabel=r"$z$ in mm")
#f.subplots_adjust(left=0.35,bottom=0.15,right=0.922,top=0.97,wspace=0.05,hspace=0.08)

f.savefig('f.pdf')
